@@ -10,8 +10,7 @@
 #pragma once
 #endif
 
-#include <boost/config/no_tr1/cmath.hpp>
-#include <math.h> // platform's ::expm1
+#include <cmath>
 #include <boost/limits.hpp>
 #include <boost/math/tools/config.hpp>
 #include <boost/math/tools/series.hpp>
@@ -20,7 +19,6 @@
 #include <boost/math/policies/error_handling.hpp>
 #include <boost/math/tools/rational.hpp>
 #include <boost/math/special_functions/math_fwd.hpp>
-#include <boost/mpl/less_equal.hpp>
 
 #ifndef BOOST_NO_LIMITS_COMPILE_TIME_CONSTANTS
 #  include <boost/static_assert.hpp>
@@ -33,7 +31,7 @@
 // This is the only way we can avoid
 // warning: non-standard suffix on floating constant [-Wpedantic]
 // when building with -Wall -pedantic.  Neither __extension__
-// nor #pragma dianostic ignored work :(
+// nor #pragma diagnostic ignored work :(
 //
 #pragma GCC system_header
 #endif
@@ -85,12 +83,12 @@ struct expm1_initializer
          do_init(tag());
       }
       template <int N>
-      static void do_init(const mpl::int_<N>&){}
-      static void do_init(const mpl::int_<64>&)
+      static void do_init(const std::integral_constant<int, N>&){}
+      static void do_init(const std::integral_constant<int, 64>&)
       {
          expm1(T(0.5));
       }
-      static void do_init(const mpl::int_<113>&)
+      static void do_init(const std::integral_constant<int, 113>&)
       {
          expm1(T(0.5));
       }
@@ -112,7 +110,7 @@ const typename expm1_initializer<T, Policy, tag>::init expm1_initializer<T, Poli
 // This version uses a Taylor series expansion for 0.5 > |x| > epsilon.
 //
 template <class T, class Policy>
-T expm1_imp(T x, const mpl::int_<0>&, const Policy& pol)
+T expm1_imp(T x, const std::integral_constant<int, 0>&, const Policy& pol)
 {
    BOOST_MATH_STD_USING
 
@@ -135,7 +133,7 @@ T expm1_imp(T x, const mpl::int_<0>&, const Policy& pol)
       return x;
    detail::expm1_series<T> s(x);
    boost::uintmax_t max_iter = policies::get_max_series_iterations<Policy>();
-#if !BOOST_WORKAROUND(__BORLANDC__, BOOST_TESTED_AT(0x582)) && !BOOST_WORKAROUND(__EDG_VERSION__, <= 245)
+#if !BOOST_WORKAROUND(BOOST_BORLANDC, BOOST_TESTED_AT(0x582)) && !BOOST_WORKAROUND(__EDG_VERSION__, <= 245)
    T result = tools::sum_series(s, policies::get_epsilon<T, Policy>(), max_iter);
 #else
    T zero = 0;
@@ -146,7 +144,7 @@ T expm1_imp(T x, const mpl::int_<0>&, const Policy& pol)
 }
 
 template <class T, class P>
-T expm1_imp(T x, const mpl::int_<53>&, const P& pol)
+T expm1_imp(T x, const std::integral_constant<int, 53>&, const P& pol)
 {
    BOOST_MATH_STD_USING
 
@@ -173,7 +171,7 @@ T expm1_imp(T x, const mpl::int_<53>&, const P& pol)
 }
 
 template <class T, class P>
-T expm1_imp(T x, const mpl::int_<64>&, const P& pol)
+T expm1_imp(T x, const std::integral_constant<int, 64>&, const P& pol)
 {
    BOOST_MATH_STD_USING
 
@@ -216,7 +214,7 @@ T expm1_imp(T x, const mpl::int_<64>&, const P& pol)
 }
 
 template <class T, class P>
-T expm1_imp(T x, const mpl::int_<113>&, const P& pol)
+T expm1_imp(T x, const std::integral_constant<int, 113>&, const P& pol)
 {
    BOOST_MATH_STD_USING
 
@@ -280,23 +278,12 @@ inline typename tools::promote_args<T>::type expm1(T x, const Policy& /* pol */)
       policies::discrete_quantile<>,
       policies::assert_undefined<> >::type forwarding_policy;
 
-   typedef typename mpl::if_c<
-      ::std::numeric_limits<result_type>::is_specialized == 0,
-      mpl::int_<0>,  // no numeric_limits, use generic solution
-      typename mpl::if_<
-         typename mpl::less_equal<precision_type, mpl::int_<53> >::type,
-         mpl::int_<53>,  // double
-         typename mpl::if_<
-            typename mpl::less_equal<precision_type, mpl::int_<64> >::type,
-            mpl::int_<64>, // 80-bit long double
-            typename mpl::if_<
-               typename mpl::less_equal<precision_type, mpl::int_<113> >::type,
-               mpl::int_<113>, // 128-bit long double
-               mpl::int_<0> // too many bits, use generic version.
-            >::type
-         >::type
-      >::type
-   >::type tag_type;
+   typedef std::integral_constant<int,
+      precision_type::value <= 0 ? 0 :
+      precision_type::value <= 53 ? 53 :
+      precision_type::value <= 64 ? 64 :
+      precision_type::value <= 113 ? 113 : 0
+   > tag_type;
 
    detail::expm1_initializer<value_type, forwarding_policy, tag_type>::force_instantiate();
    
@@ -330,7 +317,7 @@ inline typename tools::promote_args<T>::type expm1(T x)
    return expm1(x, policies::policy<>());
 }
 
-#if BOOST_WORKAROUND(__BORLANDC__, BOOST_TESTED_AT(0x564))
+#if BOOST_WORKAROUND(BOOST_BORLANDC, BOOST_TESTED_AT(0x564))
 inline float expm1(float z)
 {
    return expm1<float>(z);
